@@ -1,7 +1,4 @@
-from enum import Enum
-
-
-class Constants(str, Enum):
+class Constants:
     RESOURCE: str = "resource"
     RESOURCE_PATH: str = "path"
     RESOURCE_SERVICE: str = "service"
